# An ocean model validation using **oceanval**

Simulations were validated using the Python package **oceanval**.

You can find installation instructions for **oceanval** [here](https://github.com/pmlmodelling/oceanval).

A website with full documentation for **oceanval** is available [here](https://oceanval.readthedocs.io/en/latest/index.html).

**oceanval** is developed by Robert Wilson at [Plymouth Marine Laboratory](https://www.pml.ac.uk/), who can be contacted at <rwi@pml.ac.uk>.
